import React from "react";
import style from "./Pagination.module.css";

export const Pagination = ({ currentPage, totalPage, onPageChange }) => {
  const getPageNumbers = () => {
    const pages = [];

    if (totalPage <= 6) {
      // Show all pages if <= 6
      for (let i = 1; i <= totalPage; i++) {
        pages.push(i);
      }
    } else {
      if (currentPage <= 3) {
        pages.push(1, 2, 3, "...", totalPage);
      } else if (currentPage >= totalPage - 2) {
        pages.push(1, "...", totalPage - 2, totalPage - 1, totalPage);
      } else {
        pages.push(1, "...", currentPage, "...", totalPage);
      }
    }

    return pages;
  };

  const pageNumbers = getPageNumbers();

  return (
    <div className={style.paginationContainer}>
      {pageNumbers.map((number, index) =>
        number === "..." ? (
          <span key={index} className={style.paginationEllipsis}>
            {number}
          </span>
        ) : (
          <button
            key={number}
            onClick={() => onPageChange(number)}
            className={`${style.paginationButton} ${
              currentPage === number ? style.active : ""
            }`}
          >
            {number}
          </button>
        )
      )}

      <button
        onClick={() => onPageChange(currentPage + 1)}
        disabled={currentPage === totalPage}
        className={style.paginationNext}
      >
        Next
      </button>
    </div>
  );
};
